import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { FormattedMessage } from 'react-intl';
import CopyToClipboard from 'react-copy-to-clipboard';

import Input from 'reactstrap/lib/Input';
import Button from 'reactstrap/lib/Button';

import { IconCopyWhite } from '../../icons/icon-copy/icon-copy-white';

import { DEFAULT_RESET_STATE_TIMEOUT } from '../../../constants';
import './input-with-clipboard.scss';

export class InputWithClipboard extends Component {
  static propTypes = {
    value: PropTypes.string.isRequired,
  };

  state = {
    copied: false,
  };

  clipboardTimeout;

  componentWillUnmount() {
    if (this.clipboardTimeout) {
      clearTimeout(this.clipboardTimeout);
    }
  }

  copy = () => {
    this.setState({ copied: true });
    this.clipboardTimeout = setTimeout(this.resetCopy, DEFAULT_RESET_STATE_TIMEOUT);
  };

  resetCopy = () => {
    this.setState({ copied: false });
  };

  render() {
    const { copied } = this.state;
    const { value } = this.props;

    return (
      <div className="d-flex input-with-clipboard">
        <Input plaintext className="clipboard-text">{value}</Input>
        <CopyToClipboard text={value}>
          <Button color="primary" className="clipboard-button" onClick={this.copy}>
            {copied ? <IconCopyWhite /> : <FormattedMessage id="wallet.payment.receive.copy.button" />}
          </Button>
        </CopyToClipboard>
      </div>
    );
  }
}
